import click
from huhk.case_project.version import version as _version


@click.group()
def main():
    pass


@click.command()
@click.option('-v', '--version', help='线索版本')
@click.option('-i', '--init', help='项目key', prompt=True)
@click.option('-u', '--update', help='项目key')
def main(version=None, init=None, update=None):
    """Simple program that greets NAME for a total of COUNT times."""
    if version:
        click.echo('版本：' + _version)
    elif init:
        click.echo('init：' + _version)
    elif update:
        click.echo('update：' + _version)


if __name__ == '__main__':
    main()


from huhk.testcase.apache.data import *
from huhk.unit_apache_beam import ApacheFun


class TestFile:
    def test_file_001(self):
        path = r"C:\Users\hangkai.hu\Desktop\测试\雷达用例\活动发现页.xlsx"
        ApacheFun().read_excel(path, 0).print()

    def test_file_002(self):
        path = r"C:\Users\hangkai.hu\Desktop\测试\雷达用例\活动发现页.xlsx"
        path2 = r"C:\Users\hangkai.hu\Desktop\测试\雷达用例"
        ApacheFun().read_excel(path).write_excel(path2)


"""
@REM 创建一个新项目和一个单个应用
python manage.py  startproject ardar_test
python manage.py startapp autotest

@REM 如果关闭debug模式后，请执行以下命令将simpleui静态文件静态文件克隆到根目录
python manage.py collectstatic

@REM 执行迁移
python manage.py makemigrations
python manage.py migrate

@REM 创建admin超级管理员
python manage.py createsuperuser

@REM 三方包记录
pip freeze > requirements.txt

@REM linux 虚拟环境
mkvirtualenv -p python3.10 py310
workon py310
deactivate
rmvirtualenv venv

@REM 打包上传
python setup_set.py sdist

@REM 打包命令
python setup_set.py sdist bdist_wheel
python -m twine upload dist/*


"""


import logging
import sys
import os
import time

BASE_PATH = os.path.dirname(os.path.dirname(os.path.realpath(__file__)))
# 定义日志文件路径
LOG_PATH = os.path.join(BASE_PATH, "log")
if not os.path.exists(LOG_PATH):
    os.mkdir(LOG_PATH)


class Logger():

    def __init__(self):
        isDebug = True if sys.gettrace() else False

        self.logger = logging.getLogger("log")
        self.logger.setLevel(logging.DEBUG)
        self.formater = logging.Formatter(
            '[%(asctime)s][%(filename)s %(lineno)d][%(levelname)s]: %(message)s')
        self.console = logging.StreamHandler()
        self.console.setLevel(logging.DEBUG)
        self.console.setFormatter(self.formater)
        self.logger.addHandler(self.console)
        if isDebug:
            self.logname = os.path.join(LOG_PATH, "{}.log".format(time.strftime("%Y%m%d")))
            self.filelogger = logging.FileHandler(self.logname, mode='a', encoding="UTF-8")
            self.filelogger.setLevel(logging.DEBUG)
            self.filelogger.setFormatter(self.formater)
            self.logger.addHandler(self.filelogger)


logger = Logger().logger

if __name__ == '__main__':

    logger.info("---测试开始---")
    logger.debug("---测试结束---")
